"""At this place, we give only the messages for raising."""

def parameter_bug():
    return f"__init__() Invalid Syntax (Unexpected parameter given: extras)"

def KI_bug():
    return f"Program Interrupted by User..."

def modal_bug():
    return f"__init__() Invalid Syntax (Unexpected parameter given: mode)"
